# Forms

About this document

This document describes the Django forms provided by Softwarefabrica Django Wiki.

Contents

- Forms
  - `PageForm`
  - `PageContentForm`

# Forms

Almost all the forms are automatically generated by the generic views (see the views documentation).

There are two additional, simple forms that are used by the `v_wikipage_edit` view: `PageForm` and `PageContentForm`. These are built using the extended `ModelForm` mechaninsm provided by softwarefabrica.django.forms.

See also the models documentation, views documentation, and templates documentation.

## `PageForm`

The form used to edit/create a `Page` instance. This is always used in conjunction with `PageContentForm`.

## `PageContentForm`

The form used to create a `PageContent` instance. This is always used in conjunction with `PageForm`.